@@ -14,15 +14,17 @@ import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.cloud_assembly_schema._jsii
 import aws_cdk.core._jsii
+import aws_cdk.cx_api._jsii
 import aws_cdk.region_info._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-elasticloadbalancingv2",
-    "1.71.0",
+    "1.76.0",
     __name__[0:-6],
-    "aws-elasticloadbalancingv2@1.71.0.jsii.tgz",
+    "aws-elasticloadbalancingv2@1.76.0.jsii.tgz",
 )
 
 __all__ = [
